@@ -28,5 +28,5 @@
 
 #define QT_FEATURE_webengine_vaapi 1
 
-#define QT_FEATURE_webengine_system_poppler -1
+#define QT_FEATURE_webengine_arm64_udot_support -1
 
